"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs_1 = tslib_1.__importDefault(require("fs"));
var path_1 = tslib_1.__importDefault(require("path"));
var tsconfig_paths_webpack_plugin_1 = tslib_1.__importDefault(require("tsconfig-paths-webpack-plugin"));
var disableTypeCheck = process.env.DISABLE_TYPE_CHECKING === 'true';
function getTypeScriptWebpackRule(_plugins, resolvePlugins, options, buildTarget) {
    var configFile = (buildTarget === 'server'
        ? options.buildConfig.TS_CONFIG_SERVER
        : options.buildConfig.TS_CONFIG_CLIENT) || 'tsconfig.json';
    options.log.info("Target " + buildTarget + " using ts config file: " + configFile);
    var tsConfigPathsPluginConfig = {};
    var tsLoaderOptions = {
        compilerOptions: {
            noEmit: false,
        },
        transpileOnly: disableTypeCheck,
        experimentalWatchApi: true,
        projectReferences: true,
    };
    if (configFile) {
        tsConfigPathsPluginConfig.configFile = configFile;
        tsLoaderOptions.configFile = configFile;
    }
    resolvePlugins.push(new tsconfig_paths_webpack_plugin_1.default(tsConfigPathsPluginConfig));
    var tsLoader = {
        loader: 'ts-loader',
        options: tsLoaderOptions,
    };
    var babelConfig = path_1.default.resolve(options.buildConfig.BASE, ".babelrc");
    if (!fs_1.default.existsSync(babelConfig)) {
        babelConfig = path_1.default.resolve(process.cwd(), ".babelrc");
        if (!fs_1.default.existsSync(babelConfig)) {
            babelConfig = undefined;
        }
    }
    if (babelConfig) {
        options.log.info("Using babel config: " + babelConfig);
    }
    return {
        test: /\.tsx?$/,
        use: [
            {
                loader: 'babel-loader',
                options: {
                    extends: babelConfig,
                },
            },
            tsLoader,
        ],
    };
}
exports.getTypeScriptWebpackRule = getTypeScriptWebpackRule;
//# sourceMappingURL=ts-loader-config.js.map