import { __awaiter, __generator } from "tslib";
import path from 'path';
import SpeedMeasurePlugin from 'speed-measure-webpack-plugin';
import { ENVIRONMENTS, getWebpackConfig, TARGETS } from '../build/build';
import clean from '../clean';
import { watchtowerConfigFilename } from '../runtime/config/config';
import { writeFile } from '../runtime/util/fs';
import { webpackPromise } from '../util/webpack';
export function smp(buildConfig, webpackConfig) {
    var smpPlugin = new SpeedMeasurePlugin();
    return buildConfig.SMP ? smpPlugin.wrap(webpackConfig) : webpackConfig;
}
var buildTarget = function (log, buildConfig, target, environment) {
    if (environment === void 0) { environment = 'prod'; }
    return __awaiter(void 0, void 0, void 0, function () {
        var config;
        return __generator(this, function (_a) {
            config = getWebpackConfig(log, buildConfig, target, environment);
            if (!config) {
                return [2 /*return*/, Promise.reject("Could not load webpack configuration for " + target + "/" + environment + "!")];
            }
            return [2 /*return*/, webpackPromise(log, smp(buildConfig, config)).then(function () {
                    var runtimeConfig = {
                        ASSETS_PATH: buildConfig.ASSETS_PATH_PREFIX,
                        ASSETS_PATH_PREFIX: buildConfig.ASSETS_PATH_PREFIX,
                        BASE: '.',
                        PUBLIC_PATH: buildConfig.PUBLIC_PATH,
                        SERVER_PUBLIC_DIR: buildConfig.SERVER_PUBLIC_DIR === false ? false : 'public/',
                    };
                    // On success write out watchtower config
                    return writeFile(log, path.join(buildConfig.OUTPUT, watchtowerConfigFilename), JSON.stringify(runtimeConfig, undefined, 2));
                })];
        });
    });
};
var getBuildEnvironment = function (args) {
    for (var _i = 0, args_1 = args; _i < args_1.length; _i++) {
        var arg = args_1[_i];
        if (typeof arg !== 'string') {
            continue;
        }
        if (ENVIRONMENTS.indexOf(arg) !== -1) {
            return arg;
        }
    }
    return 'prod';
};
var getBuildTargets = function (buildConfig, args) {
    for (var _i = 0, args_2 = args; _i < args_2.length; _i++) {
        var arg = args_2[_i];
        if (!buildConfig.HAS_SERVER && arg === 'server') {
            continue;
        }
        if (typeof arg !== 'string') {
            continue;
        }
        if (TARGETS.indexOf(arg) !== -1) {
            return [arg];
        }
    }
    var defaultTargets = buildConfig.HAS_SERVER ? ['server', 'client'] : ['client'];
    return defaultTargets;
};
/**
 * Builds one or all targets in a specified environment
 * @param args
 *  [<target>] [<environment>] [-p <project root>]
 *  - target defaults to both server and client
 *  - environment defaults to prod
 *  - p: the root of the build, used for config discovery
 */
var build = function (log, buildConfig) {
    var args = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        args[_i - 2] = arguments[_i];
    }
    return __awaiter(void 0, void 0, void 0, function () {
        var targets, environment, cleanTarget, _a, targets_1, target;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    targets = getBuildTargets(buildConfig, args);
                    environment = getBuildEnvironment(args);
                    cleanTarget = buildConfig.OUTPUT;
                    return [4 /*yield*/, clean(log, cleanTarget)];
                case 1:
                    _b.sent();
                    _a = 0, targets_1 = targets;
                    _b.label = 2;
                case 2:
                    if (!(_a < targets_1.length)) return [3 /*break*/, 5];
                    target = targets_1[_a];
                    return [4 /*yield*/, buildTarget(log, buildConfig, target, environment)];
                case 3:
                    _b.sent();
                    _b.label = 4;
                case 4:
                    _a++;
                    return [3 /*break*/, 2];
                case 5: return [2 /*return*/];
            }
        });
    });
};
export default build;
//# sourceMappingURL=build.js.map