import fs from 'fs';
import path from 'path';
import TsconfigPathsPlugin from 'tsconfig-paths-webpack-plugin';
var disableTypeCheck = process.env.DISABLE_TYPE_CHECKING === 'true';
export function getTypeScriptWebpackRule(_plugins, resolvePlugins, options, buildTarget) {
    var configFile = (buildTarget === 'server'
        ? options.buildConfig.TS_CONFIG_SERVER
        : options.buildConfig.TS_CONFIG_CLIENT) || 'tsconfig.json';
    options.log.info("Target " + buildTarget + " using ts config file: " + configFile);
    var tsConfigPathsPluginConfig = {};
    var tsLoaderOptions = {
        compilerOptions: {
            noEmit: false,
        },
        transpileOnly: disableTypeCheck,
        experimentalWatchApi: true,
        projectReferences: true,
    };
    if (configFile) {
        tsConfigPathsPluginConfig.configFile = configFile;
        tsLoaderOptions.configFile = configFile;
    }
    resolvePlugins.push(new TsconfigPathsPlugin(tsConfigPathsPluginConfig));
    var tsLoader = {
        loader: 'ts-loader',
        options: tsLoaderOptions,
    };
    var babelConfig = path.resolve(options.buildConfig.BASE, ".babelrc");
    if (!fs.existsSync(babelConfig)) {
        babelConfig = path.resolve(process.cwd(), ".babelrc");
        if (!fs.existsSync(babelConfig)) {
            babelConfig = undefined;
        }
    }
    if (babelConfig) {
        options.log.info("Using babel config: " + babelConfig);
    }
    return {
        test: /\.tsx?$/,
        use: [
            {
                loader: 'babel-loader',
                options: {
                    extends: babelConfig,
                },
            },
            tsLoader,
        ],
    };
}
//# sourceMappingURL=ts-loader-config.js.map